This crate contains kube-rs compatible bindings for Kubernetes custom resources for the tests.testkube.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
tests.testkube.io/v1
ScriptTestExecutionTestTestSourceTestSuiteExecutionTestSuiteTestTrigger
tests.testkube.io/v2
ScriptTestTestSuite
tests.testkube.io/v3
TestTestSuite